(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 14.5.99 by Hendrik
 *
 * Time-stamp: <Friday 5 July 02 18:30:36 tews@ithif51>
 *
 * theories for ground signatures
 *
 * $Id: sig_theory.mli,v 1.4 2002/07/18 13:43:24 tews Exp $
 *
 *)


open Classtypes

class ccsl_isar_start_sig
  : ccsl_iface_type -> ccsl_sig_theory_type

class ccsl_isar_close_sig
  : ccsl_iface_type -> ccsl_sig_theory_type

val ccsl_sig_def_theories
  : ccsl_iface_type -> ccsl_sig_theory_type list


(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)

